'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.stdinIsTTY = exports.stdoutIsTTY = exports.handleEPIPE = exports.createErrorHandler = exports.validateAmount = exports.validateMinimum = exports.validateLifetime = undefined;

var _error = require('../utils/error');

const regExpAmount = /^\d+(\.\d{1,8})?$/; /*
                                           * LiskHQ/lisk-commander
                                           * Copyright © 2017–2018 Lisk Foundation
                                           *
                                           * See the LICENSE file at the top-level directory of this distribution
                                           * for licensing information.
                                           *
                                           * Unless otherwise agreed in a custom licensing agreement with the Lisk Foundation,
                                           * no part of this software, including this file, may be copied, modified,
                                           * propagated, or distributed except according to the terms contained in the
                                           * LICENSE file.
                                           *
                                           * Removal or modification of this copyright notice is prohibited.
                                           *
                                           */


const isStringInteger = n => {
	const parsed = parseInt(n, 10);
	return !Number.isNaN(parsed) && parsed.toString() === n;
};

const validateLifetime = exports.validateLifetime = lifetime => {
	if (!isStringInteger(lifetime)) {
		throw new _error.ValidationError('Lifetime must be an integer.');
	}
	return true;
};

const validateMinimum = exports.validateMinimum = minimum => {
	if (!isStringInteger(minimum)) {
		throw new _error.ValidationError('Minimum number of signatures must be an integer.');
	}
	return true;
};

const validateAmount = exports.validateAmount = amount => {
	if (!amount.match(regExpAmount)) {
		throw new _error.ValidationError('Amount must be a number with no more than 8 decimal places.');
	}
	return true;
};

const createErrorHandler = exports.createErrorHandler = prefix => ({ message }) => ({
	error: `${prefix}: ${message}`
});

const handleEPIPE = exports.handleEPIPE = err => {
	if (err.errno !== 'EPIPE') {
		throw err;
	}
};

const stdoutIsTTY = exports.stdoutIsTTY = () => process.stdout.isTTY;

const stdinIsTTY = exports.stdinIsTTY = () => process.stdin.isTTY;